L1.meas <- function(group, data, breaks=NULL, weights){
 imbalance(group, data, collapsed=FALSE, reduced=FALSE, breaks=breaks, weights)
}


imbalance <- function(group, data, collapsed=TRUE, reduced=TRUE, breaks=NULL, weights){
 lv <- unique(na.omit(group))


 if(length(lv)>2)
  stop("more than 2 groups")

 if(!reduced){
  data <- reduce.data(data, collapse=TRUE, breaks=breaks)
  collapsed <- TRUE
 }  
 if(!collapsed)
  data <- collapse.data(data)
  
 n <- length(data)[1]
 if(missing(weights)){
  weights <- rep(1, n)
 }

 idx1 <- which(group==lv[1])
 idx2 <- which(group==lv[2])

 n1 <- sum(weights[idx1])
 n2 <- sum(weights[idx2])

 tab <- table(data)
 cell <- attr(tab, "dimnames")[[1]]
 L1 <- 0

 for(i in cell){
  idx <- as.numeric(which(data == i))   
  jdx1 <- intersect(idx, idx1)
  jdx2 <- intersect(idx, idx2)
  m1 <- sum(weights[jdx1])/n1
  m2 <- sum(weights[jdx2])/n2
  L1 <- L1 + abs(m1-m2) 
 }
 L1
}


eval.match <- function(group, data, breaks=NULL, weights){
 if (!is.data.frame(data))
        stop("Data must be a dataframe", call. = FALSE)
 if(missing(weights)){
  weights <- rep(1, dim(data)[1])
 }
 lv <- unique(na.omit(group))
 if(length(lv)>2)
  stop("more than 2 groups")
 idx1 <- which(group==lv[1])
 idx2 <- which(group==lv[2])
 tmp <- reduce.data(data, breaks=breaks)
 
 stdmean <- function(x, wh) weighted.mean(x, w=wh, na.rm=TRUE)

 qt.w <-function(x, probs=c(0,0.25,0.5, 0.75, 1), wh){
  q <- NULL
  which(is.na(x)) -> id
  if(length(id)>0)
   x <- x[-id]
  ord <- order(x)
  x <- x[ord]
  wh <- wh[ord]
  F <- cumsum(wh)/sum(wh)
  
  for(i in probs){
    q <- c(q, x[which(F>=i)[1]])  
  }
  idx <- which(is.na(q))
  q[idx] <- max(x)
  q
}
 
 vnames <- colnames(data)
 nv <- length(vnames)
 tab <- as.data.frame(matrix(NA, nv, 8)) 
 rownames(tab) <- vnames
 colnames(tab) <- c("statistics", "L1","min", "25%",  "50%",  "75%", "max", "type")

 for (i in 1:nv){
  tab[i,2] <- L1.meas(group, tmp[i], breaks=breaks,weights=weights)
  if((is.numeric(data[,i]) | is.integer(data[,i])) ){
    tab[i,1] <- stdmean(data[idx1,i],weights[idx1]) - stdmean(data[idx2,i],weights[idx2])  
    tab[i,3:7] <- qt.w(x=data[idx1,i], wh=weights[idx1]) - qt.w(x=data[idx2,i], wh=weights[idx2])  
    tab[i,8] <- "diff"
  } else {
   t1 <- table(data[idx1,i])
   t2 <- table(data[idx2,i])
    tab[i,1] <- as.numeric(chisq.test(cbind(t1,t2))$statistic)   
    tab[i,3:7] <- NA  
    tab[i,8] <- "Chi2"
  }
 }
 tab
}

