\name{eval.match}
\alias{eval.match}
\title{Calculates several one dimensional imbalance measures}
\description{
Calculates several one dimensional imbalance measures for the original
and matched data sets}
\usage{
eval.match(group, data, breaks = NULL, weights)
}
\arguments{
 \item{group}{the group variable}
  \item{data}{the data}
  \item{breaks}{a list of vectors of cutpoints used to calculate L1 measure. See Details.}
  \item{weights}{weights}
}
\details{
This function calculate several imbalance measures.
For numeric variables the difference in means (under the column \code{statistics}, 
the difference in quantiles and the L1
measure is calculated. For categorical variables the L1 measure and the 
Chi-squared distance (under column \code{statistics}) is calculated.

If the \code{breaks} are not specified, the same approach as in 
\code{\link{cem}} is used.  Please refer to \code{\link{cem}} help
page. In this case, breaks are used to calculate the L1 measure.
  
}
\value{
  \item{value}{Table of imbalance measures}
}
\references{Stefano Iacus, Gary King, Giusseppe Porro, ``Matching for
  Casual Inference Without Balance Checking,''
  http://gking.harvard.edu/files/abs/cem-abs.shtml}
\author{Stefano Iacus, Gary King, and Giusseppe Porro}
  \examples{ data(LL)

mybr = list(re74=hist(LL$re74,plot=FALSE)$breaks, 
 re75 = hist(LL$re75,plot=FALSE)$breaks,
 age = hist(LL$age,plot=FALSE)$breaks,
 education = hist(LL$education,plot=FALSE)$breaks)
   
L1.meas(LL$treated, LL[,-c(1,9)],breaks=mybr)
eval.match(LL$treated, LL[,-c(1,9)], breaks=mybr)

# cem match: automatic bin choice
mat <- cem(treatment="treated",data=LL, drop="re78")
mat$tab
cem1.idx <- which(mat$matched)
# imbalance
L1.meas(LL$treated[cem1.idx], LL[cem1.idx,-c(1,9)],breaks=mybr)
eval.match(LL$treated[cem1.idx], LL[cem1.idx,-c(1,9)], breaks=mybr)
eval.match(LL$treated[cem1.idx], LL[cem1.idx,-c(1,9)], breaks=mybr,weights=mat$w[cem1.idx])
}
\keyword{ datagen }
