\name{multicem}
\alias{multicem}
\title{Coarsened Exact Matching for Multiply Imputed Data}
\description{
Implementation of Coarsened Exact Matching for Multiply Imputed Data
}
\usage{
multicem(treatment = NULL, datalist, data = NULL, cutpoints = NULL, drop = NULL, 
    eval.imbalance = FALSE, k2k = FALSE,  method=NULL, mpower=2, verbose = 0)
}
\arguments{
  \item{treatment}{character, name of the treatment variable}
  \item{datalist}{a list of imputed data.frame's}
  \item{data}{original data.frame with missing values}
  \item{cutpoints}{named list each describing the cutpoints for the
  variables (the names are variable names).
  Each list element is either a vector of cutpoints, a number of
  cutpoints, or
  a method for automatic bin contruction. See Details.}
  \item{drop}{a vector of variable names in the data frame to ignore
    during matching}
  \item{eval.imbalance}{boolean. See Details.}
  \item{k2k}{boolean, return k-to-k matching? Default = \code{FALSE}}
  \item{method}{distance method to use in \code{k2k} matching. See Details.}
  \item{mpower}{power of the Minkowski distance. See Details.}
  \item{verbose}{controls level of verbosity. Default=0.}
}
\details{
 Argument \code{datalist} is a list of (multiply imputed) data
 frames.  If \code{data} is not specified, the function \code{cem} is
 applied independently to each element of the list, resulting in
 separately matched data sets with different numbers of treated and
 control units.
 
 When \code{data} is specified, each multiply imputed observation is assigned to the
 stratum in which it has been matched most frequently.  In this case, the
 algorithm outputs the same matching solution for each multiply imputed
 data set (i.e., an observation, and the number of treated and control
 units matched, in one data set has the same meaning in all, and is the
 same for all)
   
 All the remaining arguments are passed to \code{cem} as specified.
}
\value{
  An object of class \code{multicem}, i.e. a list of objects of class \code{\link{cem}}
}
\references{Stefano Iacus, Gary King, Giusseppe Porro, ``Matching for
  Casual Inference Without Balance Checking,''
  http://gking.harvard.edu/files/abs/cem-abs.shtml}
\author{Stefano Iacus, Gary King, and Giusseppe Porro}
\examples{
require(Amelia)

data(LL)
n <- dim(LL)[1]
k <- dim(LL)[2]

set.seed(123)

LL1 <- LL
idx <- sample(1:n, .3*n)
invisible(sapply(idx, function(x) LL1[x,sample(2:k,1)] <<- NA))

imputed <- amelia(LL1,noms=c("black","hispanic","treated","married","nodegree","u74","u75"))[1:5] 

# without information on which observation has missing values
mat1 <- multicem("treated", datalist=imputed, drop="re78")
#str(mat1, max.lev=1)
mat1$match1$tab
mat1$match2$tab

# ATT estimation
out <- att(mat1, re78 ~ treated, data=imputed)

# with information about missingness
mat2 <- multicem("treated", datalist=imputed, drop="re78", data=LL1)
#str(mat2, max.lev=1)
mat2$match1$tab
mat2$match2$tab

# ATT estimation
out <- att(mat2, re78 ~ treated, data=imputed)
}
\keyword{multivariate}
\keyword{datagen}


